#!/bin/sh
#
# This file is part of reference hash utilities
#
# Copyright (C) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
#
# Contact: Markku Kylänpää <ext-markku.kylanpaa@nokia.com>
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301 USA
#
# Authors: Markku Kylänpää 2008-2009
#
# Test script for refhashutils package
#
TESTFILE=/usr/bin/refhashutils-test-helloworld
TESTFILE2=/usr/bin/refhashutils-test-helloworld.sh
LOGDIR=/tmp/refhashutils-tests
LOGFILE=$LOGDIR/testlog
HASHMAKE=refhashmake
HASHFEED=refhashfeeder
OK=0

if [ ! -d $LOGDIR ]; then
    mkdir $LOGDIR
fi

# Check reference hash calculation
$HASHMAKE -a -c -r -o com.nokia.maemo -f $TESTFILE > $LOGDIR/newhash 2> $LOGFILE
RESULT=$?
if [ $RESULT -ne 0 ]; then
    echo "[FAIL] Reference hash calculation ($RESULT)"
    OK=-1
else
    echo "[PASS] Reference hash calculation"
fi

# Trying to feed generated file to /dev/null
$HASHFEED -n $LOGDIR/newhash > $LOGFILE 2>&1
RESULT=$?
if [ $RESULT -ne 0 ]; then
    echo "[FAIL] Reference hash feed ($RESULT)"
    OK=-1
else
    echo "[PASS] Reference hash feed"
fi

# Check reference hash calculation
$HASHMAKE -c -a -r -o com.nokia.maemo -f $TESTFILE2 > $LOGDIR/newhash2 2> $LOGFILE
RESULT=$?
if [ $RESULT -ne 0 ]; then
    echo "[FAIL] Reference hash calculation ($RESULT)"
    OK=-1
else
    if [ -f $LOGDIR/newhash2 ]; then
	fgrep "S 15 com.nokia.maemo H 40 e26c061bc203a25d68cc6f20ed77542de7e127d0 R 21 usr/bin/helloworld.sh" $LOGDIR/newhash2 > $LOGDIR/hash
	RESULT=$?
	if [ $RESULT -ne 0 ]; then
	    echo "[FAIL] Reference hash calculation ($RESULT)"
	    OK=-1
	else
	    echo "[PASS] Reference hash calculation"
	fi
    else
	echo "[FAIL] Reference hash calculation (no hash output)"
	OK=-1
    fi
fi

exit $OK
